@@ -157,6 +157,10 @@ display_contributors (gpointer data)
 	AnimationData *ani_data;
 
 	static GnomeCanvasItem *contributor = NULL;
+	/* FIXME: this is a workaround for a libgnomecanvas bug. See bug #329165.
+	 * When removing it, we should not forget to remove the "ugh" part of
+	 * animate_contributor() */
+	static GnomeCanvasItem *contributor_rect = NULL;
 	static GnomeCanvasItem *contributor_text = NULL;
 
 	if (contrib_i >= G_N_ELEMENTS (contributors))
@@ -170,6 +174,12 @@ display_contributors (gpointer data)
 					       gnome_canvas_group_get_type (),
 					       NULL);
 
+		contributor_rect =
+			gnome_canvas_item_new (GNOME_CANVAS_GROUP (contributor),
+					       gnome_canvas_rect_get_type (),
+					       "fill_color", "White",
+					       NULL);
+
 		text = g_strdup_printf ("<b>%s</b>", 
 					contributors[contrib_order[contrib_i]]);
 		contributor_text =
@@ -288,6 +298,8 @@ display_introduction_message (gpointer data)
 	AnimationData *ani_data;
 
 	static GnomeCanvasItem *intro = NULL;
+	/* FIXME: this is a workaround for a libgnomecanvas bug. See bug #329165. */
+	static GnomeCanvasItem *intro_rect = NULL;
 	static GnomeCanvasItem *intro_text = NULL;
 	static gint intro_i = 0;
 
@@ -312,6 +324,16 @@ display_introduction_message (gpointer data)
 					       gnome_canvas_group_get_type (),
 					       NULL);
 
+		intro_rect =
+			gnome_canvas_item_new (GNOME_CANVAS_GROUP (intro),
+					       gnome_canvas_rect_get_type (),
+					       "fill_color", "White",
+					       "x1", -4.0,
+					       "y1", -4.0,
+					       "x2", 304.0,
+					       "y2", 84.0,
+					       NULL);
+
 		intro_text =
 			gnome_canvas_item_new (GNOME_CANVAS_GROUP (intro),
 					       gnome_canvas_rich_text_get_type (),
